@@ -1,4 +1,4 @@
-#!/bin/bash -
+#!/usr/bin/env bash
 # nbdkit
 # Copyright (C) 2014 Red Hat Inc.
 # All rights reserved.
@@ -33,14 +33,13 @@
 
 set -e
 set -x
+source ./functions.sh
 
 # Test nbdkit -f option.
 
 rm -f foreground.pid foreground.sock
 
-../src/nbdkit \
-    -f -P foreground.pid -U foreground.sock \
-    ../plugins/example1/.libs/nbdkit-example1-plugin.so &
+nbdkit -f -P foreground.pid -U foreground.sock example1 &
 bg_pid=$!
 
 # We may have to wait a short time for the pid file to appear.
